EditEphemeralMessageText

Struct EditEphemeralMessageText 

pub struct EditEphemeralMessageText { /* private fields */ }
Edits an ephemeral text message.

Note that it is not guaranteed that the user will receive the message edit event, especially if they are offline.

Implementations

Source

impl EditEphemeralMessageText

pub fn rich_message<T>( identity: T, rich_message: InputRichMessage, ) -> EditEphemeralMessageText

Creates a new EditEpehemeralMessageText.

Arguments
  • identity - Identity of the ephemeral message.
  • text - New text of the message; 1-4096 characters after entity parsing.
pub fn text<A, B>(identity: A, text: B) -> EditEphemeralMessageText

Creates a new EditEpehemeralMessageText.

Arguments
  • identity - Identity of the ephemeral message.
  • text - New text of the message; 1-4096 characters after entity parsing.

Sets a new link preview options.

Arguments
  • value - Link preview generation options for the message.
pub fn with_reply_markup<T>(self, value: T) -> EditEphemeralMessageText

Sets a new reply markup.

Arguments
  • value - An object for an inline keyboard