InputSticker

Struct InputSticker 

pub struct InputSticker { /* private fields */ }
Represents a metadata of a sticker to be added to a sticker set.

Implementations

Source

impl InputSticker

pub fn new<A, B, C>( sticker: A, emoji_list: B, format: StickerFormat, ) -> InputSticker
where A: Into<InputFile>, B: IntoIterator<Item = C>, C: Into<String>,

Creates a new InputSticker.

Arguments
  • sticker - The added sticker.
  • emoji_list - List of 1-20 emoji associated with the sticker.
  • format - Format of the sticker.
pub fn with_keywords<A, B>(self, value: A) -> InputSticker
where A: IntoIterator<Item = B>, B: Into<String>,

Sets a new list of keywords.

Arguments
  • value - List of 0-20 search keywords for the sticker with total length of up to 64 characters; for “regular” and “custom_emoji” stickers only.
pub fn with_mask_position(self, value: MaskPosition) -> InputSticker

Sets a new mask position.

Arguments
  • value - Position where the mask should be placed on faces; for “mask” stickers only.