pub struct LivePhoto {
pub duration: i64,
pub file_id: String,
pub file_unique_id: String,
pub height: i64,
pub width: i64,
pub file_size: Option<i64>,
pub mime_type: Option<String>,
pub photo: Option<Vec<PhotoSize>>,
}Expand description
Represents a live photo.
Fields
duration: i64Duration of the video in seconds as defined by the sender.
file_id: StringIdentifier for the video file which can be used to download or reuse the file.
file_unique_id: StringUnique identifier for the video file which is supposed to be the same over time and for different bots.
Can’t be used to download or reuse the file.
height: i64Video height as defined by the sender.
width: i64Video width as defined by the sender.
file_size: Option<i64>File size in bytes.
mime_type: Option<String>MIME type of the file as defined by the sender.
photo: Option<Vec<PhotoSize>>Available sizes of the corresponding static photo.