SendRichMessage

Struct SendRichMessage 

pub struct SendRichMessage { /* private fields */ }
Sends rich messages.

If the message contains a block with a media element, then the bot must have the right to send the media to the chat.

Implementations

Source

impl SendRichMessage

pub fn new<T>(chat_id: T, rich_message: InputRichMessage) -> SendRichMessage
where T: Into<ChatId>,

Creates a new SendRichMessage.

Arguments
  • chat_id - Unique identifier of the target chat.
  • rich_message - The message to be sent.
pub fn with_allow_paid_broadcast(self, value: bool) -> SendRichMessage

Sets a new value for the allow_paid_broadcast flag.

Arguments
  • value - Whether to allow up to 1000 messages per second, ignoring broadcasting limits for a fee of 0.1 Telegram Stars per message.

The relevant Stars will be withdrawn from the bot’s balance.

pub fn with_business_connection_id<T>(self, value: T) -> SendRichMessage
where T: Into<String>,

Sets a new business connection ID.

Arguments
  • value - Unique identifier of the business connection.
pub fn with_direct_messages_topic_id(self, value: i64) -> SendRichMessage

Sets a new direct messages topic ID

  • value - Identifier of the direct messages topic to which the message will be sent.

Required if the message is sent to a direct messages chat.

pub fn with_disable_notification(self, value: bool) -> SendRichMessage

Sets a new value for the disable_notification flag.

Arguments
  • value - Indicates whether to send the message silently or not; a user will receive a notification without sound.
pub fn with_ephemeral_message_parameters<T>(self, value: T) -> SendRichMessage

Sets the new ephemeral message parameters.

Arguments
  • value - An object containing the parameters of the ephemeral message to send.
pub fn with_message_effect_id<T>(self, value: T) -> SendRichMessage
where T: Into<String>,

Sets a new message effect ID.

Arguments
  • value - Unique identifier of the message effect to be added to the message; for private chats only.
pub fn with_message_thread_id(self, value: i64) -> SendRichMessage

Sets a new message thread ID.

Arguments
  • value - Unique identifier of the target message thread; for forum supergroups and private chats of bots with forum topic mode enabled only.
pub fn with_protect_content(self, value: bool) -> SendRichMessage

Sets a new value for the protect_content flag.

Arguments
  • value - Indicates whether to protect the contents of the sent message from forwarding and saving.
pub fn with_reply_markup<T>(self, value: T) -> SendRichMessage
where T: Into<ReplyMarkup>,

Sets a new reply markup.

Arguments
  • value - Reply markup.
pub fn with_reply_parameters(self, value: ReplyParameters) -> SendRichMessage

Sets new reply parameters.

Arguments
  • value - Description of the message to reply to.
pub fn with_suggested_post_parameters( self, value: SuggestedPostParameters, ) -> SendRichMessage

Sets a new suggested post parameters.

Arguments
  • value - An object containing the parameters of the suggested post to send.

For direct messages chats only.

If the message is sent as a reply to another suggested post, then that suggested post is automatically declined.